# Table of Contents

- [rest-apis](<./rest-apis.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [REST APIs](<./REST-APIs.md>)
  - [Overview](<./REST-APIs/Overview.md>)
  - [Available APIs](<./REST-APIs/Available-APIs.md>)
  - [Authentication](<./REST-APIs/Authentication.md>)
  - [OpenAPI Explorer](<./REST-APIs/OpenAPI-Explorer.md>)
  - [Use Cases](<./REST-APIs/Use-Cases.md>)
